powered by
Crumble control parameters
crumble_control( crossfit_folds = 10L, mlr3superlearner_folds = 10L, zprime_folds = 1L, epochs = 100L, learning_rate = 0.01, batch_size = 64, device = c("cpu", "cuda", "mps") )
A list of control parameters
[numeric(1)] The number of crossfit folds.
numeric(1)
[numeric(1)] The number of `mlr3superlearner` folds.
[numeric(1)] The number of folds to split that data into for calculating Z'. With larger sample sizes, a larger number will increase speed.
[numeric(1)] The number of epochs to train the neural network.
[numeric(1)] The learning rate for the neural network.
[numeric(1)] The batch size for mini-batch gradient descent.
[character(1)] Object representing the device on which a torch_tensor is or will be allocated.
character(1)
torch_tensor
if (torch::torch_is_installed()) crumble_control(crossfit_folds = 5)
Run the code above in your browser using DataLab